==> kendra-2.20.95-sources.jar: software/amazon/awssdk/services/kendra/paginators/ListGroupsOlderThanOrderingIdIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.kendra.paginators;

import java.util.Iterator;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.kendra.KendraClient;
import software.amazon.awssdk.services.kendra.model.ListGroupsOlderThanOrderingIdRequest;
import software.amazon.awssdk.services.kendra.model.ListGroupsOlderThanOrderingIdResponse;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.kendra.KendraClient#listGroupsOlderThanOrderingIdPaginator(software.amazon.awssdk.services.kendra.model.ListGroupsOlderThanOrderingIdRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.kendra.model.ListGroupsOlderThanOrderingIdResponse} that can be used to
 * iterate through all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.kendra.paginators.ListGroupsOlderThanOrderingIdIterable responses = client.listGroupsOlderThanOrderingIdPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.kendra.paginators.ListGroupsOlderThanOrderingIdIterable responses = client
 *             .listGroupsOlderThanOrderingIdPaginator(request);
 *     for (software.amazon.awssdk.services.kendra.model.ListGroupsOlderThanOrderingIdResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.kendra.paginators.ListGroupsOlderThanOrderingIdIterable responses = client.listGroupsOlderThanOrderingIdPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Please notice that the configuration of MaxResults won't limit the number of results you get with the paginator.
 * It only limits the number of results in each page.</b>
 * </p>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #listGroupsOlderThanOrderingId(software.amazon.awssdk.services.kendra.model.ListGroupsOlderThanOrderingIdRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class ListGroupsOlderThanOrderingIdIterable implements SdkIterable<ListGroupsOlderThanOrderingIdResponse> {
    private final KendraClient client;

    private final ListGroupsOlderThanOrderingIdRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public ListGroupsOlderThanOrderingIdIterable(KendraClient client, ListGroupsOlderThanOrderingIdRequest firstRequest) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.nextPageFetcher = new ListGroupsOlderThanOrderingIdResponseFetcher();
    }

    @Override
    public Iterator<ListGroupsOlderThanOrderingIdResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    private class ListGroupsOlderThanOrderingIdResponseFetcher implements SyncPageFetcher<ListGroupsOlderThanOrderingIdResponse> {
        @Override
        public boolean hasNextPage(ListGroupsOlderThanOrderingIdResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public ListGroupsOlderThanOrderingIdResponse nextPage(ListGroupsOlderThanOrderingIdResponse previousPage) {
            if (previousPage == null) {
                return client.listGroupsOlderThanOrderingId(firstRequest);
            }
            return client.listGroupsOlderThanOrderingId(firstRequest.toBuilder().nextToken(previousPage.nextToken()).build());
        }
    }
}

==> kendra-2.25.16-sources.jar: software/amazon/awssdk/services/kendra/paginators/ListGroupsOlderThanOrderingIdIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.kendra.paginators;

import java.util.Iterator;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.kendra.KendraClient;
import software.amazon.awssdk.services.kendra.internal.UserAgentUtils;
import software.amazon.awssdk.services.kendra.model.ListGroupsOlderThanOrderingIdRequest;
import software.amazon.awssdk.services.kendra.model.ListGroupsOlderThanOrderingIdResponse;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.kendra.KendraClient#listGroupsOlderThanOrderingIdPaginator(software.amazon.awssdk.services.kendra.model.ListGroupsOlderThanOrderingIdRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.kendra.model.ListGroupsOlderThanOrderingIdResponse} that can be used to
 * iterate through all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.kendra.paginators.ListGroupsOlderThanOrderingIdIterable responses = client.listGroupsOlderThanOrderingIdPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.kendra.paginators.ListGroupsOlderThanOrderingIdIterable responses = client
 *             .listGroupsOlderThanOrderingIdPaginator(request);
 *     for (software.amazon.awssdk.services.kendra.model.ListGroupsOlderThanOrderingIdResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.kendra.paginators.ListGroupsOlderThanOrderingIdIterable responses = client.listGroupsOlderThanOrderingIdPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Please notice that the configuration of MaxResults won't limit the number of results you get with the paginator.
 * It only limits the number of results in each page.</b>
 * </p>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #listGroupsOlderThanOrderingId(software.amazon.awssdk.services.kendra.model.ListGroupsOlderThanOrderingIdRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class ListGroupsOlderThanOrderingIdIterable implements SdkIterable<ListGroupsOlderThanOrderingIdResponse> {
    private final KendraClient client;

    private final ListGroupsOlderThanOrderingIdRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public ListGroupsOlderThanOrderingIdIterable(KendraClient client, ListGroupsOlderThanOrderingIdRequest firstRequest) {
        this.client = client;
        this.firstRequest = UserAgentUtils.applyPaginatorUserAgent(firstRequest);
        this.nextPageFetcher = new ListGroupsOlderThanOrderingIdResponseFetcher();
    }

    @Override
    public Iterator<ListGroupsOlderThanOrderingIdResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    private class ListGroupsOlderThanOrderingIdResponseFetcher implements SyncPageFetcher<ListGroupsOlderThanOrderingIdResponse> {
        @Override
        public boolean hasNextPage(ListGroupsOlderThanOrderingIdResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public ListGroupsOlderThanOrderingIdResponse nextPage(ListGroupsOlderThanOrderingIdResponse previousPage) {
            if (previousPage == null) {
                return client.listGroupsOlderThanOrderingId(firstRequest);
            }
            return client.listGroupsOlderThanOrderingId(firstRequest.toBuilder().nextToken(previousPage.nextToken()).build());
        }
    }
}
